@@ -45,6 +45,7 @@ pub enum Context {
     Context192(blake2b::Context<128>),
     Context224(blake2b::Context<224>),
     Context256(blake2b::Context<256>),
+    Context264(blake2b::Context<264>),
     Context288(blake2b::Context<288>),
     Context320(blake2b::Context<320>),
     Context352(blake2b::Context<352>),
@@ -63,6 +64,7 @@ macro_rules! ctx_pass {
             Context::Context192(ctx) => ctx.$name ($($input)*),
             Context::Context224(ctx) => ctx.$name ($($input)*),
             Context::Context256(ctx) => ctx.$name ($($input)*),
+            Context::Context264(ctx) => ctx.$name ($($input)*),
             Context::Context288(ctx) => ctx.$name ($($input)*),
             Context::Context320(ctx) => ctx.$name ($($input)*),
             Context::Context352(ctx) => ctx.$name ($($input)*),
@@ -83,6 +85,7 @@ impl Context {
             Context::Context192(_) => 24,
             Context::Context224(_) => 28,
             Context::Context256(_) => 32,
+            Context::Context264(_) => 33,
             Context::Context288(_) => 36,
             Context::Context320(_) => 40,
             Context::Context352(_) => 44,
@@ -129,6 +132,7 @@ impl Blake2b {
             24 => Context::Context192(blake2b::Context::new()),
             28 => Context::Context224(blake2b::Context::new()),
             32 => Context::Context256(blake2b::Context::new()),
+            33 => Context::Context264(blake2b::Context::new()),
             36 => Context::Context288(blake2b::Context::new()),
             40 => Context::Context320(blake2b::Context::new()),
             44 => Context::Context352(blake2b::Context::new()),
@@ -155,6 +159,10 @@ impl Blake2b {
             24 => Context::Context192(blake2b::Context::new_keyed(key)),
             28 => Context::Context224(blake2b::Context::new_keyed(key)),
             32 => Context::Context256(blake2b::Context::new_keyed(key)),
+            33 => Context::Context264(blake2b::Context::new_keyed(key)),
+            36 => Context::Context288(blake2b::Context::new_keyed(key)),
+            40 => Context::Context320(blake2b::Context::new_keyed(key)),
+            44 => Context::Context352(blake2b::Context::new_keyed(key)),
             48 => Context::Context384(blake2b::Context::new_keyed(key)),
             64 => Context::Context512(blake2b::Context::new_keyed(key)),
             _ => panic!("outlen > 0 && outlen <= 64"),
