@@ -20,7 +20,6 @@
 // option. This file may not be copied, modified, or distributed
 // except according to those terms.
 
-use crate::cryptoutil::{copy_memory, write_u32_be};
 use crate::mac::Mac;
 use alloc::vec::Vec;
 use core::iter::repeat;
@@ -42,9 +41,7 @@ fn calculate_block<M: Mac>(
 ) {
     // Perform the 1st iteration. The output goes directly into block
     mac.input(salt);
-    let mut idx_buf = [0u8; 4];
-    write_u32_be(&mut idx_buf, idx);
-    mac.input(&idx_buf);
+    mac.input(&idx.to_be_bytes());
     mac.raw_result(block);
     mac.reset();
 
@@ -107,7 +104,7 @@ pub fn pbkdf2<M: Mac>(mac: &mut M, salt: &[u8], c: u32, output: &mut [u8]) {
             let mut tmp: Vec<u8> = repeat(0).take(os).collect();
             calculate_block(mac, salt, c, idx, &mut scratch[..], &mut tmp[..]);
             let chunk_len = chunk.len();
-            copy_memory(&tmp[..chunk_len], chunk);
+            chunk[0..chunk_len].copy_from_slice(&tmp[..chunk_len]);
         }
     }
 }
